'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _react = require('react');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var propTypes = {
  active: _propTypes2.default.bool.isRequired,
  interimResults: _propTypes2.default.bool,
  lang: _propTypes2.default.string,
  onEnd: _propTypes2.default.func,
  onResult: _propTypes2.default.func,
  onUnsupported: _propTypes2.default.func
};

var defaultProps = {
  interimResults: true,
  lang: '',
  onEnd: function onEnd() {},
  onResult: function onResult() {},
  onUnsupported: function onUnsupported() {}
};

var SpeechRekognition = function SpeechRekognition(props) {
  var recognition = (0, _react.useRef)(null);

  var _useState = (0, _react.useState)(false),
      _useState2 = _slicedToArray(_useState, 2),
      started = _useState2[0],
      setStarted = _useState2[1];

  var active = props.active,
      interimResults = props.interimResults,
      lang = props.lang,
      onUnsupported = props.onUnsupported,
      onEnd = props.onEnd,
      onResult = props.onResult;


  var processResult = function processResult(event) {
    var transcript = Array.from(event.results).map(function (result) {
      return result[0];
    }).map(function (result) {
      return result.transcript;
    }).join('');

    onResult(transcript);
  };

  var start = function start() {
    recognition.current.onresult = processResult;
    // SpeechRecognition stops automatically after inactivity
    // We want it to keep going until we tell it to stop
    recognition.current.onend = function () {
      return recognition.current.start();
    };
    if (!started) {
      recognition.current.start();
      setStarted(true);
    }
  };

  var stop = function stop() {
    if (!started) return;
    recognition.current.onend = function () {};
    recognition.current.stop();
    setStarted(false);
    onEnd();
  };

  (0, _react.useEffect)(function () {
    window.SpeechRecognition = window.SpeechRecognition || window.webkitSpeechRecognition;
    if (!window.SpeechRecognition) {
      onUnsupported();
      return;
    }

    recognition.current = new window.SpeechRecognition();
  }, []);

  // Start and stop listening
  (0, _react.useEffect)(function () {
    if (!recognition.current) return;
    if (active) {
      start();
    } else {
      stop();
    }
  }, [active]);

  // Update language
  (0, _react.useEffect)(function () {
    if (!recognition.current) return;
    recognition.current.lang = lang;
  }, [lang]);

  // Update interimResults
  (0, _react.useEffect)(function () {
    if (!recognition.current) return;
    recognition.current.interimResults = interimResults;
  }, [interimResults]);

  return null;
};

var areEqual = function areEqual(prevProps, nextProps) {
  return ['active', 'lang', 'interimResults'].every(function (key) {
    return prevProps[key] === nextProps[key];
  });
};

SpeechRekognition.propTypes = propTypes;
SpeechRekognition.defaultProps = defaultProps;

exports.default = (0, _react.memo)(SpeechRekognition, areEqual);