'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _react = require('react');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var propTypes = {
  active: _propTypes2.default.bool.isRequired,
  interimResults: _propTypes2.default.bool,
  lang: _propTypes2.default.string,
  onEnd: _propTypes2.default.func,
  onResult: _propTypes2.default.func,
  onUnsupported: _propTypes2.default.func
};

var defaultProps = {
  voiceURI: '',
  onEnd: function onEnd() {},
  onResult: function onResult() {},
  onUnsupported: function onUnsupported() {}
};

var SpeechSynthesis = function SpeechSynthesis(props) {
  var active = props.active,
      text = props.text,
      onUnsupported = props.onUnsupported,
      onEnd = props.onEnd,
      onVoicesLoaded = props.onVoicesLoaded,
      voiceURI = props.voiceURI;

  var _useState = (0, _react.useState)(null),
      _useState2 = _slicedToArray(_useState, 2),
      voices = _useState2[0],
      setVoices = _useState2[1];

  var _useState3 = (0, _react.useState)(null),
      _useState4 = _slicedToArray(_useState3, 2),
      voice = _useState4[0],
      setVoice = _useState4[1];

  var getUtterance = function getUtterance() {
    // Firefox requires won't repeat an utterance that has been
    // spoken, so we need to create a new instance each time
    var utterance = new window.SpeechSynthesisUtterance();
    utterance.text = text;
    utterance.voice = voice;
    utterance.onend = onEnd;
    return utterance;
  };

  var processVoices = function processVoices(voiceOptions) {
    setVoices(voiceOptions);
    onVoicesLoaded(voiceOptions);
  };

  var getVoices = function getVoices() {
    // Firefox seems to have voices upfront and never calls the
    // voiceschanged event
    var voiceOptions = window.speechSynthesis.getVoices();
    if (voiceOptions.length > 0) {
      processVoices(voiceOptions);
      return;
    }

    window.speechSynthesis.onvoiceschanged = function (event) {
      voiceOptions = event.target.getVoices();
      processVoices(voiceOptions);
    };
  };

  (0, _react.useEffect)(function () {
    if (!window.speechSynthesis) {
      onUnsupported();
      return;
    }
    getVoices();
  }, []);

  // Change voice
  (0, _react.useEffect)(function () {
    if (voices) {
      var newVoice = voices.find(function (option) {
        return option.voiceURI === voiceURI;
      });
      setVoice(newVoice);
    }
  }, [voiceURI, voices]);

  (0, _react.useEffect)(function () {
    if (active) {
      window.speechSynthesis.speak(getUtterance());
    } else {
      window.speechSynthesis.cancel();
    }
  }, [active]);

  return null;
};

SpeechSynthesis.propTypes = propTypes;
SpeechSynthesis.defaultProps = defaultProps;

exports.default = (0, _react.memo)(SpeechSynthesis);